/* private.h: various private functions

   Copyright 2009, Novell, Inc.

   This file is part of the Mate Library.

   The Mate Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Mate Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Mate Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
   Boston, MA 02110-1301, USA.

   Author: Vincent Untz <vuntz@gnome.org>
*/

#ifndef __MATE_DESKTOP_PRIVATE_H__
#define __MATE_DESKTOP_PRIVATE_H__

#include <glib.h>

G_BEGIN_DECLS

void _mate_desktop_init_i18n (void);

G_END_DECLS

#endif
